@@ -72,17 +72,20 @@ public:
      */
     void showItems(const KFileItemList& items);
 
-    /**
-     * Opens a menu which allows to configure which meta information
-     * should be shown.
-     *
-     * TODO: Move this code to the class InformationPanel
-     */
-    void configureSettings(const QList<QAction*>& customContextMenuActions);
+    void setPreviewVisible(bool visible);
+
+    KFileItemList items();
 
 signals:
     void urlActivated( const QUrl& url );
 
+public slots:
+    /**
+     * Is invoked after the file meta data configuration dialog has been
+     * closed and refreshes the visibility of the meta data.
+     */
+    void refreshMetaData();
+
 protected:
     /** @see QObject::eventFilter() */
     bool eventFilter(QObject* obj, QEvent* event) override;
@@ -108,12 +111,6 @@ private slots:
 
     void slotHasVideoChanged(bool hasVideo);
 
-    /**
-     * Is invoked after the file meta data configuration dialog has been
-     * closed and refreshes the visibility of the meta data.
-     */
-    void refreshMetaData();
-
 private:
     /**
      * Sets the text for the label \a m_nameLabel and assures that the
