@@ -19,7 +19,8 @@
 #ifndef STARTUPSETTINGSPAGE_H
 #define STARTUPSETTINGSPAGE_H
 
-#include <settings/settingspagebase.h>
+#include "settings/settingspagebase.h"
+
 #include <QUrl>
 
 class QLineEdit;
@@ -37,13 +38,13 @@ class StartupSettingsPage : public SettingsPageBase
 
 public:
     StartupSettingsPage(const QUrl& url, QWidget* parent);
-    virtual ~StartupSettingsPage();
+    ~StartupSettingsPage() override;
 
     /** @see SettingsPageBase::applySettings() */
-    virtual void applySettings() Q_DECL_OVERRIDE;
+    void applySettings() override;
 
     /** @see SettingsPageBase::restoreDefaults() */
-    virtual void restoreDefaults() Q_DECL_OVERRIDE;
+    void restoreDefaults() override;
 
 private slots:
     void slotSettingsChanged();
