@@ -21,9 +21,10 @@
 #ifndef VIEWPROPERTIES_H
 #define VIEWPROPERTIES_H
 
-#include <views/dolphinview.h>
-#include <QUrl>
 #include "dolphin_export.h"
+#include "views/dolphinview.h"
+
+#include <QUrl>
 
 class ViewPropertySettings;
 /**
@@ -153,6 +154,12 @@ private:
      */
     void convertNameRoleToTextRole();
 
+    /**
+     * Provides backward compatibility with .directory files created with
+     * Dolphin < 16.11.70: Converts the old name-role "date" to "modificationtime"
+     */
+
+    void convertDateRoleToModificationTimeRole();
     /**
      * Returns true, if \a filePath is part of the home-path (see QDir::homePath()).
      */
